pub struct AnvilLevel {
pub ignored_chunks: HashSet<ChunkPos>,
/* private fields */
}Fields
ignored_chunks: HashSet<ChunkPos>The set of chunk positions that should not be loaded or unloaded by the anvil system.
This set is empty by default, but you can modify it at any time.
Implementations
Sourceimpl AnvilLevel
impl AnvilLevel
pub fn new<R: Into<PathBuf>>(world_root: R, biomes: &BiomeRegistry) -> Self
Sourcepub fn force_chunk_load(&mut self, pos: ChunkPos)
pub fn force_chunk_load(&mut self, pos: ChunkPos)
Forces a chunk to be loaded at a specific position in this world. This
will bypass AnvilLevel::ignored_chunks.
Note that the chunk will be unloaded next tick unless it has been added
to AnvilLevel::ignored_chunks or it is in view of a client.
This has no effect if a chunk at the position is already present.