pub struct RegionFolder {
pub write_options: WriteOptions,
/* private fields */
}Fields
write_options: WriteOptionsOptions to use for writing the chunk.
Implementations
Sourceimpl RegionFolder
impl RegionFolder
pub fn new<R: Into<PathBuf>>(region_root: R) -> Self
Sourcepub fn get_chunk<S>(
&mut self,
pos_x: i32,
pos_z: i32,
) -> Result<Option<RawChunk<S>>, RegionError>
pub fn get_chunk<S>( &mut self, pos_x: i32, pos_z: i32, ) -> Result<Option<RawChunk<S>>, RegionError>
Gets the raw chunk at the given chunk position.
Returns Ok(Some(chunk)) if the chunk exists and no errors occurred
loading it. Returns Ok(None) if the chunk does not exist and no
errors occurred attempting to load it. Returns Err(_) if an error
occurred attempting to load the chunk.
Sourcepub fn delete_chunk(
&mut self,
pos_x: i32,
pos_z: i32,
) -> Result<bool, RegionError>
pub fn delete_chunk( &mut self, pos_x: i32, pos_z: i32, ) -> Result<bool, RegionError>
Deletes the chunk at the given chunk position, returning whether the chunk existed before it was deleted.
Note that this only marks the chunk as deleted so that it cannot be retrieved, and can be overwritten by other chunks later. It does not decrease the size of the region file.
Sourcepub fn set_chunk<S>(
&mut self,
pos_x: i32,
pos_z: i32,
chunk: &Compound<S>,
) -> Result<(), RegionError>
pub fn set_chunk<S>( &mut self, pos_x: i32, pos_z: i32, chunk: &Compound<S>, ) -> Result<(), RegionError>
Sets the raw chunk at the given position, overwriting the old chunk if it exists.
Sourcepub fn all_chunk_positions(
&mut self,
) -> Result<impl Iterator<Item = Result<(i32, i32), RegionError>> + '_, RegionError>
pub fn all_chunk_positions( &mut self, ) -> Result<impl Iterator<Item = Result<(i32, i32), RegionError>> + '_, RegionError>
Returns an iterator over all existing chunks in all regions.